(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     11092,        326]
NotebookOptionsPosition[      5032,        174]
NotebookOutlinePosition[     10220,        295]
CellTagsIndexPosition[     10177,        292]
WindowFrame->Generic*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["ccgrg",
  FontSlant->"Italic"],
 " objectives"
}], "Title",
 TextAlignment->Right,
 FontSize->18,
 FontColor->GrayLevel[0.5]],

Cell["\<\
Tensor analysis package for general relativity,  
gravitation and cosmology.
\
\>", "Text",
 CellChangeTimes->{{3.574738284100885*^9, 3.574738332688664*^9}, {
  3.5868708347665443`*^9, 3.5868708445789614`*^9}, {3.591817290021348*^9, 
  3.591817291487751*^9}, {3.5918197782619815`*^9, 3.591819792118774*^9}},
 TextAlignment->Center,
 FontSize->16],

Cell[CellGroupData[{

Cell["Functional programming  ", "Subsubsection"],

Cell["\tsee: guide/FunctionalProgramming", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Functional representation of tensors", "Subsubsection"],

Cell["\<\
Tensor is a function (not array). The innermost sequence of arguments is \
reserved for tensor indexes.\
\>", "Text",
 CellChangeTimes->{
  3.5721036202790484`*^9, {3.5874148525281954`*^9, 3.5874148551333995`*^9}, 
   3.591819195197632*^9, {3.591820860559467*^9, 3.59182086258747*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parker-Christensen (reverse) index convention", "Subsubsection"],

Cell["\<\
Tensor indexes run through
\tcovariant:  i\[Element]{1,dim} ,
\tcontravariant:  i\[Element]{-dim,-1} 
- Parker-Christensen (reverse!)  index convention (+co,-contra). \
\>", "Text",
 CellChangeTimes->{{3.591819443824853*^9, 3.591819491272567*^9}}],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"i", " ", "k"}]], TraditionalForm]],
  CellChangeTimes->{{3.5698712206702905`*^9, 3.569871258437957*^9}}],
 "  \[Rule] T[i,k]"
}], "Text",
 CellChangeTimes->{
  3.572103498286834*^9, {3.591819365542375*^9, 3.591819438498548*^9}, 
   3.5918195049633493`*^9}],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["T", 
     RowBox[{"i", " "}]], "k"], TraditionalForm]],
  CellChangeTimes->{{3.5698712206702905`*^9, 3.569871258437957*^9}}],
 " \[Rule] T[i,-k]"
}], "Text",
 CellChangeTimes->{
  3.5721035113128567`*^9, {3.5918193746738977`*^9, 3.591819406344709*^9}, 
   3.5918195068274565`*^9}],

Cell[TextData[{
 "\t ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SuperscriptBox["T", "i"], "k"], TraditionalForm]],
  CellChangeTimes->{{3.5698712206702905`*^9, 3.569871258437957*^9}}],
 "  \[Rule] T[-i,-k]"
}], "Text",
 CellChangeTimes->{
  3.5721035231376777`*^9, {3.591819390589808*^9, 3.5918193960031176`*^9}, 
   3.5918195082215357`*^9}],

Cell["\<\
In the GRG applications the index values 1 and -1 refer to time components.\
\>", "Text",
 CellChangeTimes->{{3.591819270677949*^9, 3.5918193078380747`*^9}, {
  3.591819338297817*^9, 3.5918193393368764`*^9}, {3.591821685239315*^9, 
  3.591821686144117*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Non-strict (lazy) evaluation, whenever possible", "Subsubsection"],

Cell["\<\
Nothing is computed in advance. Once computed, instantly cached. \
Constructions of the form:\
\>", "Text",
 CellChangeTimes->{{3.5749566621171227`*^9, 3.5749566648159275`*^9}}],

Cell["\tf[i_, k_] := f[i, k] = expr[i, k]", "Text",
 CellChangeTimes->{{3.5918196432432585`*^9, 3.5918196519067545`*^9}, {
  3.5918198270197706`*^9, 3.5918198441677513`*^9}}],

Cell[TextData[{
 "(memoizing functions) are widely employed in the Package.\nsee: ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " tutorial/FunctionsThatRememberValuesTheyHaveFound"
}], "Text",
 CellChangeTimes->{{3.5722770629175014`*^9, 3.5722770710607157`*^9}, {
  3.5918190869994435`*^9, 3.5918191187712607`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Correspondence to the physical notation", "Subsubsection",
 CellChangeTimes->{{3.5918183521794143`*^9, 3.5918183591728144`*^9}}],

Cell["", "Text",
 CellChangeTimes->{
  3.591818477655591*^9, {3.5918185255473304`*^9, 3.59181852904753*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Modifiable content", "Subsubsection",
 CellChangeTimes->{{3.5918188501118946`*^9, 3.5918188539691153`*^9}}],

Cell["\<\
Limited number of predefined tensors. The emphasis is on utilities (covariant \
derivative, Lie derivative, projection tensor, etc.) to create the \
user-defined tensors.  
\t\t\t\
\>", "Text",
 CellChangeTimes->{
  3.5722770781431284`*^9, {3.591817833242733*^9, 3.5918178821565304`*^9}, {
   3.5918188885540934`*^9, 3.5918189042799926`*^9}, {3.5918190205166407`*^9, 
   3.5918190249468946`*^9}, {3.591854003635371*^9, 3.591854027347413*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{
  Scaled[
   Rational[3, 4]], 
  Scaled[1]},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
WindowFrame->"Generic",
ShowSelection->True,
FrontEndVersion->"9.0 for Microsoft Windows (32-bit) (January 25, 2013)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Background colors", "Subsection", 
       CellChangeTimes -> {3.5689765261927013`*^9}], 
      Cell[
       CellGroupData[{
         Cell[
         "Background", "Subsubsection", 
          CellChangeTimes -> {3.568976573569985*^9}], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, 
          CellBracketOptions -> {"Color" -> GrayLevel[0]}, 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 9, Background -> GrayLevel[0.94902]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Background for input cell", "Subsubsection", 
          CellChangeTimes -> {3.5689765583287582`*^9}], 
         Cell[
          StyleData["Input"], CellMargins -> {{66, 10}, {5, 7}}, Evaluatable -> 
          True, CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
          True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
          DefaultFormatType -> DefaultInputFormatType, 
          "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
          FormatType -> InputForm, ShowStringCharacters -> True, NumberMarks -> 
          True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, 
          CounterIncrements -> "Input", FontFamily -> "Helvetica", FontSize -> 
          12, FontWeight -> "Bold", Background -> 
          RGBColor[
           0.8941176470588236, 0.8941176470588236, 0.8941176470588236]]}, 
        Closed]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Headings and text", "Subsection", 
       CellChangeTimes -> {3.568981227090465*^9}, FontFamily -> "Candara"], 
      Cell[
       CellGroupData[{
         Cell[
         "Headings", "Subsubsection", 
          CellChangeTimes -> {3.5689812390088863`*^9}], 
         Cell[
          StyleData["Title"], CellFrame -> {{0, 0}, {1, 0}}, CellDingbat -> 
          None, CellMargins -> {{27, Inherited}, {8, 34}}, 
          CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> False, 
          CellFrameMargins -> 4, CellFrameColor -> 
          RGBColor[1, 0.611765, 0.317647], DefaultNewInlineCellStyle -> 
          "None", LineSpacing -> {1, 2}, FontFamily -> "Candara", FontSize -> 
          24, FontWeight -> "Plain"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{0, 0}, {0.5, 0}}, 
             ShowGroupOpener -> True, 
             CellMargins -> {{60, Inherited}, {8, 12}}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", FontFamily -> 
             "Candara", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
             "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "Masked" -> False, "Outline" -> False, "Shadow" -> False, 
               "StrikeThrough" -> False, "Underline" -> False}], 
            Cell[
             BoxData[" "], "Input", CellFrame -> {{0, 0}, {0.5, 0}}, 
             CellChangeTimes -> {3.5689766331932898`*^9}, FontFamily -> 
             "Candara"]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> None, ShowGroupOpener -> 
             True, CellMargins -> {{60, Inherited}, {2, 10}}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", FontFamily -> 
             "Candara", FontSize -> 16, FontWeight -> "Plain"], 
            Cell[
             BoxData[" "], "Input", 
             CellChangeTimes -> {3.5689772404087563`*^9}, FontFamily -> 
             "Candara"]}, Open]], 
         Cell[
          StyleData["Subsubsection"], CellDingbat -> None, ShowGroupOpener -> 
          True, FontFamily -> "Candara", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontTracking -> "Plain", 
          FontVariations -> {
           "Masked" -> False, "Outline" -> False, "Shadow" -> False, 
            "StrikeThrough" -> False, "Underline" -> False}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Text", "Subsubsection", CellChangeTimes -> {3.568980449396245*^9}], 
         Cell[
          StyleData["Text"], FontFamily -> "Candara", FontSize -> 12, 
          FontWeight -> "Plain", FontSlant -> "Plain", 
          FontVariations -> {
           "StrikeThrough" -> False, "Underline" -> False}]}, Closed]]}, 
     Open]]}, Visible -> False, FrontEndVersion -> 
  "9.0 for Microsoft Windows (32-bit) (January 25, 2013)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 152, 7, 69, "Title"],
Cell[735, 31, 356, 9, 77, "Text"],
Cell[CellGroupData[{
Cell[1116, 44, 49, 0, 29, "Subsubsection"],
Cell[1168, 46, 50, 0, 28, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1255, 51, 61, 0, 23, "Subsubsection"],
Cell[1319, 53, 295, 6, 28, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1651, 64, 70, 0, 29, "Subsubsection"],
Cell[1724, 66, 257, 6, 79, "Text"],
Cell[1984, 74, 340, 11, 28, "Text"],
Cell[2327, 87, 366, 12, 28, "Text"],
Cell[2696, 101, 350, 11, 30, "Text"],
Cell[3049, 114, 267, 5, 28, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3353, 124, 72, 0, 29, "Subsubsection"],
Cell[3428, 126, 187, 4, 28, "Text"],
Cell[3618, 132, 174, 2, 28, "Text"],
Cell[3795, 136, 322, 7, 45, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4154, 148, 134, 1, 29, "Subsubsection"],
Cell[4291, 151, 108, 2, 28, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[4436, 158, 113, 1, 23, "Subsubsection"],
Cell[4552, 161, 452, 9, 45, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
