(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     33245,        883]
NotebookOptionsPosition[     25575,        673]
NotebookOutlinePosition[     30916,        800]
CellTagsIndexPosition[     30831,        795]
WindowFrame->Generic*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["opening calculations", "Title",
 FontSize->18,
 FontColor->GrayLevel[0.5]],

Cell[CellGroupData[{

Cell["Initial section", "Section"],

Cell[CellGroupData[{

Cell["Package", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Needs", "[", "\"\<ccgrg`\>\"", "]"}], 
  ";"}], "\n", "version"}], "Input"],

Cell[BoxData[
 StyleBox["\<\"ccgrg - Copernicus Center General Relativity Package for \
Mathematica 8/9\"\>",
  StripOnInput->False,
  FontFamily->"Helvetica",
  FontSlant->Italic]], "Print",
 CellChangeTimes->{3.6023304920807524`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"ver-1.04\"\>", ",", "\<\"Wed 27 Nov 2013 08:04:23\"\>", ",", 
   "52831"}], "}"}]], "Output",
 CellChangeTimes->{{3.5721050338982673`*^9, 3.572105074645539*^9}, 
   3.5725445517555428`*^9, 3.572546986448799*^9, 3.5749568505342536`*^9, 
   3.574957133861951*^9, 3.577281903864457*^9, 3.5773446780416803`*^9, 
   3.581746345006434*^9, 3.586413523575911*^9, 3.5865310101820464`*^9, 
   3.5869893579495554`*^9, 3.5885723453837104`*^9, 3.5908102649550333`*^9, 
   3.5908102959366875`*^9, 3.590810326731142*^9, 3.590824142929244*^9, 
   3.5909016440808134`*^9, 3.5909096753361845`*^9, 3.590941065845427*^9, 
   3.5911976167542553`*^9, 3.5912250603837385`*^9, 3.5912622706301603`*^9, 
   3.5912666331934223`*^9, 3.5912912041972036`*^9, 3.591481964220477*^9, 
   3.591605898187705*^9, 3.591799751733245*^9, 3.5918229408911257`*^9, 
   3.5918858427416296`*^9, 3.592462878323467*^9, 3.5929705948010197`*^9, 
   3.5944638461669397`*^9, 3.594464007506168*^9, 3.5944795109321213`*^9, 
   3.5945247973069897`*^9, 3.6022248106081276`*^9, 3.6022250712670364`*^9, 
   3.6023304920907526`*^9}]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Download ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mth.drac.oa.uj.edu.pl/mufiles/00002/ccgrg/package/ccgrg_pack.\
zip"], None},
  ButtonNote->
   "http://mth.drac.oa.uj.edu.pl/mufiles/00002/ccgrg/package/ccgrg_pack.zip"],
 StyleBox[ButtonBox["ccgrg",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mth.drac.oa.uj.edu.pl/mufiles/00002/ccgrg/package/ccgrg_pack.\
zip"], None},
  ButtonNote->
   "http://mth.drac.oa.uj.edu.pl/mufiles/00002/ccgrg/package/ccgrg_pack.zip"],
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.572524842630431*^9, 3.5725248687292767`*^9}},
 TextAlignment->Right]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Coordinates and the metric tensor", "Section"],

Cell[CellGroupData[{

Cell["Definitions", "Subsection"],

Cell["\<\
Calculation starts with the coordinate names specification and the definition \
of the metric tensor (both in the matrix form)\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "r", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"B", "[", "r", "]"}]}], ",", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"M", "[", "r", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"4", " ", "\[Pi]", " ", "r"}], ")"}]}]}], ")"}]}], ",", 
      RowBox[{"r", "^", "2"}], ",", 
      RowBox[{
       RowBox[{"r", "^", "2"}], " ", 
       RowBox[{
        RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}], "^", "2"}]}]}], "}"}], 
    "]"}]}], ";"}]}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Opening procedure", "Section"],

Cell["The opening procedure open[x,g] :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"open", "[", 
  RowBox[{"x", ",", "g"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"new metric:  \"\>"},
    {"\<\"  \"\>"},
    {
     TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {
          RowBox[{"-", 
           RowBox[{"B", "[", "r", "]"}]}], "0", "0", "0"},
         {"0", 
          FractionBox["1", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{"M", "[", "r", "]"}], 
             RowBox[{"4", " ", "\[Pi]", " ", "r"}]]}]], "0", "0"},
         {"0", "0", 
          SuperscriptBox["r", "2"], "0"},
         {"0", "0", "0", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}], "2"]}]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
      Function[BoxForm`e$, 
       MatrixForm[BoxForm`e$]]]},
    {"\<\" \"\>"},
    {
     RowBox[{"\<\"simplification method: \"\>", " ", "Together"}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{{3.5721050359106708`*^9, 3.572105076455142*^9}, 
   3.57254455380366*^9, 3.572546988474915*^9, 3.574956852297057*^9, 
   3.574957135765155*^9, 3.57728190562726*^9, 3.5773446798824835`*^9, 
   3.581746347018838*^9, 3.586413526461916*^9, 3.5865310135828524`*^9, 
   3.5869893598059587`*^9, 3.588572347442914*^9, 3.5908102675446377`*^9, {
   3.5908103095711117`*^9, 3.590810328696745*^9}, 3.5908241450976477`*^9, 
   3.5909016462492175`*^9, 3.590909681451395*^9, 3.590941085860262*^9, 
   3.5911976203422613`*^9, 3.5912250630201426`*^9, 3.591262274405367*^9, 
   3.5912666359546275`*^9, 3.591291207457609*^9, 3.5914819678864837`*^9, 
   3.5916059011673098`*^9, 3.5917997546032495`*^9, 3.5918229446819324`*^9, 
   3.5918858459552355`*^9, 3.5924628810066714`*^9, 3.592970598021204*^9, 
   3.5944638487970905`*^9, 3.5944640102323236`*^9, 3.594479513908292*^9, 
   3.5945247999131384`*^9, 3.6022248123882294`*^9, 3.6022250730931406`*^9, 
   3.6023304923807526`*^9}]
}, Open  ]],

Cell["\<\
Opening causes that all functions defined in the package will refer to this \
specific space.\
\>", "Text",
 CellChangeTimes->{{3.574760425565866*^9, 3.5747605280047255`*^9}, {
  3.5747606486086235`*^9, 3.574760651587794*^9}}],

Cell[TextData[{
 "The opening procedure ",
 StyleBox["open",
  FontSlant->"Italic"],
 "[x,g]  converts both matrices x and g into tensors (see \
Tensor,vector,scalar):\n\t x\[DoubleDagger]   (",
 StyleBox["coordinateExt",
  FontSlant->"Italic"],
 ") -  for coordinates, and\n\t g\[DoubleDagger]   (",
 StyleBox["metrixExt ",
  FontSlant->"Italic"],
 ")  -  for metric tensor"
}], "Text",
 CellChangeTimes->{3.5721076278240232`*^9, 3.572277233909402*^9}],

Cell[TextData[{
 "Opening can be repeated arbitrary many times during the current session \
(for instance, by subsequent evaluating of  the entire notebook). If both x \
and g are the same, all previously computed values are preserved. If any of x \
or g change, the cached tensor values are cleared (see section  ",
 StyleBox["Memory content",
  FontSlant->"Italic"],
 ")."
}], "Text",
 CellChangeTimes->{{3.57210773412261*^9, 3.572107738724618*^9}, 
   3.5722772428950176`*^9, {3.574760348110436*^9, 3.5747603496685247`*^9}, {
   3.5747605502119956`*^9, 3.5747605543552322`*^9}, 3.590947251836856*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tensor indices", "Section"],

Cell[CellGroupData[{

Cell["Coordinates", "Subsubsection"],

Cell["\<\
Tensor indices are the function arguments. Indices run through: covariant i\
\[Element]{1,dim} , contravariant i\[Element]{-dim,-1} - the (reverse!)  \
Parker-Christensen index convention (+co,-contra). \
\>", "Text",
 CellChangeTimes->{{3.5772820269330735`*^9, 3.577282035138688*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"x\[DoubleDagger]", "[", 
  RowBox[{"-", "1"}], "]"}], "\n", 
 RowBox[{"x\[DoubleDagger]", "[", 
  RowBox[{"-", "2"}], "]"}]}], "Input"],

Cell[BoxData["t"], "Output",
 CellChangeTimes->{{3.5721050362226715`*^9, 3.5721050767671423`*^9}, 
   3.572544554258686*^9, 3.572546988929941*^9, 3.574956852655857*^9, 
   3.574957136279956*^9, 3.5772819063136616`*^9, 3.5773446803972845`*^9, 
   3.581746347330838*^9, 3.5864135273667173`*^9, 3.586531013972853*^9, 
   3.5869893601023593`*^9, 3.5885723478641148`*^9, 3.590810268199839*^9, {
   3.590810309773912*^9, 3.590810328993146*^9}, 3.5908241455188484`*^9, 
   3.5909016468264184`*^9, 3.5909096822313967`*^9, 3.590941086297063*^9, 
   3.5911976214186635`*^9, 3.591225064970146*^9, 3.591262275606569*^9, 
   3.5912666376706305`*^9, 3.5912912088148117`*^9, 3.591481969150086*^9, 
   3.5916059030861135`*^9, 3.591799756173251*^9, 3.5918229454151335`*^9, 
   3.5918858481860394`*^9, 3.5924628825822744`*^9, 3.592970600262332*^9, 
   3.5944638503141775`*^9, 3.594464011816415*^9, 3.5944795161624207`*^9, 
   3.594524801769245*^9, 3.602224812905259*^9, 3.6022250733071527`*^9, 
   3.602330492410753*^9}],

Cell[BoxData["r"], "Output",
 CellChangeTimes->{{3.5721050362226715`*^9, 3.5721050767671423`*^9}, 
   3.572544554258686*^9, 3.572546988929941*^9, 3.574956852655857*^9, 
   3.574957136279956*^9, 3.5772819063136616`*^9, 3.5773446803972845`*^9, 
   3.581746347330838*^9, 3.5864135273667173`*^9, 3.586531013972853*^9, 
   3.5869893601023593`*^9, 3.5885723478641148`*^9, 3.590810268199839*^9, {
   3.590810309773912*^9, 3.590810328993146*^9}, 3.5908241455188484`*^9, 
   3.5909016468264184`*^9, 3.5909096822313967`*^9, 3.590941086297063*^9, 
   3.5911976214186635`*^9, 3.591225064970146*^9, 3.591262275606569*^9, 
   3.5912666376706305`*^9, 3.5912912088148117`*^9, 3.591481969150086*^9, 
   3.5916059030861135`*^9, 3.591799756173251*^9, 3.5918229454151335`*^9, 
   3.5918858481860394`*^9, 3.5924628825822744`*^9, 3.592970600262332*^9, 
   3.5944638503141775`*^9, 3.594464011816415*^9, 3.5944795161624207`*^9, 
   3.594524801769245*^9, 3.602224812905259*^9, 3.6022250733071527`*^9, 
   3.6023304924207525`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Metric tensor", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "g\[DoubleDagger]"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"Extended metric tensor: g\[DoubleDagger][m,n] \
=\!\(\*SubscriptBox[\(g\), \(mn\)]\),  g\[DoubleDagger][-m,-n] \
=\!\(\*SuperscriptBox[\(g\), \(mn\)]\),  g\[DoubleDagger][m,-n] \
=\!\(\*SuperscriptBox[SubscriptBox[\(\[Delta]\), \(m\)], \(n\)]\)\\ng\
\[DoubleDagger] is short name for metricExt. (\[DoubleDagger] is used only \
with the single-letter tensor names.)\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6023304926607533`*^9},
 CellTags->"Info3602334092-6566558"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"g\[DoubleDagger]", "[", 
  RowBox[{"1", ",", "1"}], "]"}], "\n", 
 RowBox[{"g\[DoubleDagger]", "[", 
  RowBox[{"2", ",", "2"}], "]"}], "\n", 
 RowBox[{"g\[DoubleDagger]", "[", 
  RowBox[{
   RowBox[{"-", "2"}], ",", 
   RowBox[{"-", "2"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"B", "[", "r", "]"}]}]], "Output",
 CellChangeTimes->{{3.5721050368778725`*^9, 3.5721050774223433`*^9}, 
   3.572544555360749*^9, 3.572546990049005*^9, 3.5749568536230593`*^9, 
   3.5749571373407574`*^9, 3.5772819071872635`*^9, 3.577344681426886*^9, 
   3.5817463482044396`*^9, 3.5864135293791213`*^9, 3.586531014877655*^9, 
   3.5869893607263603`*^9, 3.588572348675316*^9, 3.5908102690578403`*^9, {
   3.590810310397913*^9, 3.5908103295547466`*^9}, 3.59082414636125*^9, 
   3.59090164787162*^9, 3.5909096836041985`*^9, 3.5909410872330647`*^9, 
   3.5911976226198654`*^9, 3.5912250662805486`*^9, 3.591262276916971*^9, 
   3.591266639059033*^9, 3.591291210234414*^9, 3.591481970351288*^9, 
   3.591605904474516*^9, 3.5917997577232533`*^9, 3.591822946273135*^9, 
   3.5918858495432415`*^9, 3.5924628839706764`*^9, 3.592970601698414*^9, 
   3.5944638522432876`*^9, 3.594464013273498*^9, 3.5944795182455397`*^9, 
   3.5945248036183505`*^9, 3.602224813916317*^9, 3.6022250740021925`*^9, 
   3.6023304928207536`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", "\[Pi]", " ", "r"}], 
  RowBox[{
   RowBox[{"4", " ", "\[Pi]", " ", "r"}], "-", 
   RowBox[{"M", "[", "r", "]"}]}]]], "Output",
 CellChangeTimes->{{3.5721050368778725`*^9, 3.5721050774223433`*^9}, 
   3.572544555360749*^9, 3.572546990049005*^9, 3.5749568536230593`*^9, 
   3.5749571373407574`*^9, 3.5772819071872635`*^9, 3.577344681426886*^9, 
   3.5817463482044396`*^9, 3.5864135293791213`*^9, 3.586531014877655*^9, 
   3.5869893607263603`*^9, 3.588572348675316*^9, 3.5908102690578403`*^9, {
   3.590810310397913*^9, 3.5908103295547466`*^9}, 3.59082414636125*^9, 
   3.59090164787162*^9, 3.5909096836041985`*^9, 3.5909410872330647`*^9, 
   3.5911976226198654`*^9, 3.5912250662805486`*^9, 3.591262276916971*^9, 
   3.591266639059033*^9, 3.591291210234414*^9, 3.591481970351288*^9, 
   3.591605904474516*^9, 3.5917997577232533`*^9, 3.591822946273135*^9, 
   3.5918858495432415`*^9, 3.5924628839706764`*^9, 3.592970601698414*^9, 
   3.5944638522432876`*^9, 3.594464013273498*^9, 3.5944795182455397`*^9, 
   3.5945248036183505`*^9, 3.602224813916317*^9, 3.6022250740021925`*^9, 
   3.6023304928307533`*^9}],

Cell[BoxData[
 RowBox[{"1", "-", 
  FractionBox[
   RowBox[{"M", "[", "r", "]"}], 
   RowBox[{"4", " ", "\[Pi]", " ", "r"}]]}]], "Output",
 CellChangeTimes->{{3.5721050368778725`*^9, 3.5721050774223433`*^9}, 
   3.572544555360749*^9, 3.572546990049005*^9, 3.5749568536230593`*^9, 
   3.5749571373407574`*^9, 3.5772819071872635`*^9, 3.577344681426886*^9, 
   3.5817463482044396`*^9, 3.5864135293791213`*^9, 3.586531014877655*^9, 
   3.5869893607263603`*^9, 3.588572348675316*^9, 3.5908102690578403`*^9, {
   3.590810310397913*^9, 3.5908103295547466`*^9}, 3.59082414636125*^9, 
   3.59090164787162*^9, 3.5909096836041985`*^9, 3.5909410872330647`*^9, 
   3.5911976226198654`*^9, 3.5912250662805486`*^9, 3.591262276916971*^9, 
   3.591266639059033*^9, 3.591291210234414*^9, 3.591481970351288*^9, 
   3.591605904474516*^9, 3.5917997577232533`*^9, 3.591822946273135*^9, 
   3.5918858495432415`*^9, 3.5924628839706764`*^9, 3.592970601698414*^9, 
   3.5944638522432876`*^9, 3.594464013273498*^9, 3.5944795182455397`*^9, 
   3.5945248036183505`*^9, 3.602224813916317*^9, 3.6022250740021925`*^9, 
   3.6023304928307533`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tensors defined in the package", "Subsubsection"],

Cell[TextData[{
 StyleBox["open",
  FontSlant->"Italic"],
 "[x,g]  associates all tensors with the specified manifold (coordinate \
system x and metric tensor g). "
}], "Text",
 CellChangeTimes->{
  3.5722772548758388`*^9, {3.5865311120502253`*^9, 3.5865311236410456`*^9}}],

Cell["For instance:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tRicciR", "[", 
  RowBox[{"2", ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    SuperscriptBox["r", "2"], " ", 
    SuperscriptBox[
     RowBox[{"B", "[", "r", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "\[Pi]", " ", "r"}], "-", 
      RowBox[{"M", "[", "r", "]"}]}], ")"}]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     SuperscriptBox[
      RowBox[{"B", "[", "r", "]"}], "2"], " ", 
     RowBox[{"M", "[", "r", "]"}]}], "-", 
    RowBox[{"r", " ", 
     RowBox[{"B", "[", "r", "]"}], " ", 
     RowBox[{"M", "[", "r", "]"}], " ", 
     RowBox[{
      SuperscriptBox["B", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "+", 
    RowBox[{"4", " ", "\[Pi]", " ", 
     SuperscriptBox["r", "3"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["B", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"M", "[", "r", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["B", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
    RowBox[{"4", " ", "r", " ", 
     SuperscriptBox[
      RowBox[{"B", "[", "r", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["M", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"B", "[", "r", "]"}], " ", 
     RowBox[{
      SuperscriptBox["B", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], " ", 
     RowBox[{
      SuperscriptBox["M", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "-", 
    RowBox[{"8", " ", "\[Pi]", " ", 
     SuperscriptBox["r", "3"], " ", 
     RowBox[{"B", "[", "r", "]"}], " ", 
     RowBox[{
      SuperscriptBox["B", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"B", "[", "r", "]"}], " ", 
     RowBox[{"M", "[", "r", "]"}], " ", 
     RowBox[{
      SuperscriptBox["B", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5721050370338726`*^9, 3.572105077562744*^9}, 
   3.5725445556267643`*^9, 3.5725469902480164`*^9, 3.5749568537790594`*^9, 
   3.5749571374967575`*^9, 3.5772819073432636`*^9, 3.5773446815828867`*^9, 
   3.58174634834484*^9, 3.5864135297847223`*^9, 3.5865310150492554`*^9, 
   3.5869893608979607`*^9, 3.5885723488625164`*^9, 3.590810269245041*^9, {
   3.5908103106007137`*^9, 3.590810329695147*^9}, 3.5908241465796504`*^9, 
   3.5909016480432205`*^9, 3.590909683853799*^9, 3.590941087404665*^9, 
   3.591197622838266*^9, 3.591225066498949*^9, 3.5912622770885715`*^9, 
   3.591266639246233*^9, 3.591291210515215*^9, 3.591481970522888*^9, 
   3.591605904661716*^9, 3.591799757913254*^9, 3.5918229464447355`*^9, 
   3.591885849714842*^9, 3.592462884189077*^9, 3.592970602112438*^9, 
   3.5944638524903016`*^9, 3.594464013498511*^9, 3.594479518550557*^9, 
   3.5945248038423634`*^9, 3.6022248141393294`*^9, 3.6022250742242055`*^9, 
   3.6023304928807535`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tRiemannR", "[", 
  RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"B", "[", "r", "]"}], " ", 
    RowBox[{"M", "[", "r", "]"}], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "-", 
   RowBox[{"4", " ", "\[Pi]", " ", 
    SuperscriptBox["r", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["B", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
   RowBox[{"r", " ", 
    RowBox[{"M", "[", "r", "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["B", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
   RowBox[{"r", " ", 
    RowBox[{"B", "[", "r", "]"}], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], " ", 
    RowBox[{
     SuperscriptBox["M", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "+", 
   RowBox[{"8", " ", "\[Pi]", " ", 
    SuperscriptBox["r", "2"], " ", 
    RowBox[{"B", "[", "r", "]"}], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "-", 
   RowBox[{"2", " ", "r", " ", 
    RowBox[{"B", "[", "r", "]"}], " ", 
    RowBox[{"M", "[", "r", "]"}], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}]}], 
  RowBox[{"4", " ", "r", " ", 
   RowBox[{"B", "[", "r", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", "\[Pi]", " ", "r"}], "-", 
     RowBox[{"M", "[", "r", "]"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.5721050373926735`*^9, 3.572105077999545*^9}, 
   3.572544555847777*^9, 3.5725469904460278`*^9, 3.5749568539350595`*^9, 
   3.574957137683958*^9, 3.5772819075148635`*^9, 3.577344681816887*^9, 
   3.58174634850084*^9, 3.5864135299407225`*^9, 3.5865310152052555`*^9, 
   3.5869893612567616`*^9, 3.5885723490185165`*^9, 3.5908102693854413`*^9, {
   3.5908103109595137`*^9, 3.5908103298355474`*^9}, 3.590824146720051*^9, 
   3.5909016481992207`*^9, 3.5909096840565996`*^9, 3.5909410875918655`*^9, 
   3.5911976229786663`*^9, 3.5912250666705494`*^9, 3.5912622772289715`*^9, 
   3.591266639386634*^9, 3.5912912107024145`*^9, 3.5914819706788883`*^9, 
   3.5916059048021164`*^9, 3.591799758053254*^9, 3.5918229465851355`*^9, 
   3.5918858498552427`*^9, 3.5924628843294773`*^9, 3.5929706022674465`*^9, 
   3.5944638526673117`*^9, 3.594464013638519*^9, 3.5944795187645693`*^9, 
   3.594524803996372*^9, 3.602224814291338*^9, 3.602225074594227*^9, 
   3.6023304929007535`*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simplification method", "Section",
 CellChangeTimes->{{3.586531001446031*^9, 3.586531004051236*^9}}],

Cell[TextData[{
 "Default simplification level is ",
 StyleBox["Together",
  FontSlant->"Italic"],
 ". One can increase this level by setting optional argument"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"open", "[", 
   RowBox[{"x", ",", "g", ",", 
    RowBox[{"simplification", "->", "Simplify"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5865310251424727`*^9, 3.5865310372324944`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"new metric:  \"\>"},
    {"\<\"  \"\>"},
    {
     TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {
          RowBox[{"-", 
           RowBox[{"B", "[", "r", "]"}]}], "0", "0", "0"},
         {"0", 
          FractionBox["1", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{"M", "[", "r", "]"}], 
             RowBox[{"4", " ", "\[Pi]", " ", "r"}]]}]], "0", "0"},
         {"0", "0", 
          SuperscriptBox["r", "2"], "0"},
         {"0", "0", "0", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}], "2"]}]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
      Function[BoxForm`e$, 
       MatrixForm[BoxForm`e$]]]},
    {"\<\" \"\>"},
    {
     RowBox[{"\<\"simplification method: \"\>", " ", "Simplify"}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{{3.5721050399354777`*^9, 3.572105080245949*^9}, 
   3.572544558614935*^9, 3.572546993037176*^9, 3.574956856228264*^9, 
   3.5749571397743616`*^9, 3.577281909948468*^9, 3.5773446842192907`*^9, 
   3.5817463509656444`*^9, 3.586413532545927*^9, {3.5865310153612556`*^9, 
   3.586531043144904*^9}, 3.5869893639711657`*^9, 3.588572363978943*^9, 
   3.5908103426431694`*^9, 3.590824160869275*^9, 3.590901660882043*^9, 
   3.5909097090166435`*^9, 3.5909411072946997`*^9, 3.591197635053087*^9, 
   3.5912250681213517`*^9, 3.591262278445774*^9, 3.5912666404942355`*^9, 
   3.5912912120752172`*^9, 3.591481971958091*^9, 3.591605906096919*^9, 
   3.591799759003255*^9, 3.591822947505537*^9, 3.591885850822444*^9, 
   3.592462885468279*^9, 3.592970603420513*^9, 3.5944638537113714`*^9, 
   3.5944640146625776`*^9, 3.594479519854632*^9, 3.5945248050304313`*^9, 
   3.602224815443404*^9, 3.602225075627286*^9, 3.6023304931407537`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "open", "]"}]], "Input",
 CellChangeTimes->{{3.58653105214612*^9, 3.5865310617557373`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"simplification", "\[Rule]", "Together"}], "}"}]], "Output",
 CellChangeTimes->{3.5865310630505395`*^9, 3.5869893642519665`*^9, 
  3.5885723643221436`*^9, 3.5908103429551706`*^9, 3.590824161228076*^9, 
  3.590901661240844*^9, 3.590909709453444*^9, 3.5909411076223*^9, 
  3.591197635365088*^9, 3.5912250685113525`*^9, 3.5912622787733746`*^9, 
  3.591266640821836*^9, 3.591291212434018*^9, 3.5914819722856913`*^9, 
  3.5916059065025196`*^9, 3.591799759403256*^9, 3.591822947864338*^9, 
  3.5918858511656446`*^9, 3.59246288590508*^9, 3.592970603811535*^9, 
  3.594463854088393*^9, 3.5944640150476*^9, 3.594479520228653*^9, 
  3.5945248054074526`*^9, 3.602224815822426*^9, 3.602225075957305*^9, 
  3.602330493200754*^9}]
}, Open  ]],

Cell["\<\
Increasing the simplification level may substantially lengthen the time of \
computation.\
\>", "Text",
 CellChangeTimes->{{3.572277296605912*^9, 3.572277299991118*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{
  Scaled[
   Rational[3, 4]], 
  Scaled[1]},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
WindowFrame->"Generic",
ShowSelection->True,
FrontEndVersion->"9.0 for Microsoft Windows (32-bit) (January 25, 2013)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Background colors", "Subsection", 
       CellChangeTimes -> {3.5689765261927013`*^9}], 
      Cell[
       CellGroupData[{
         Cell[
         "Background", "Subsubsection", 
          CellChangeTimes -> {3.568976573569985*^9}], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, 
          CellBracketOptions -> {"Color" -> GrayLevel[0]}, 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 9, Background -> GrayLevel[0.94902]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Background for input cell", "Subsubsection", 
          CellChangeTimes -> {3.5689765583287582`*^9}], 
         Cell[
          StyleData["Input"], CellMargins -> {{66, 10}, {5, 7}}, Evaluatable -> 
          True, CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
          True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
          DefaultFormatType -> DefaultInputFormatType, 
          "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
          FormatType -> InputForm, ShowStringCharacters -> True, NumberMarks -> 
          True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, 
          CounterIncrements -> "Input", FontFamily -> "Helvetica", FontSize -> 
          12, FontWeight -> "Bold", Background -> 
          RGBColor[
           0.8941176470588236, 0.8941176470588236, 0.8941176470588236]]}, 
        Closed]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Headings and text", "Subsection", 
       CellChangeTimes -> {3.568981227090465*^9}, FontFamily -> "Candara"], 
      Cell[
       CellGroupData[{
         Cell[
         "Headings", "Subsubsection", 
          CellChangeTimes -> {3.5689812390088863`*^9}], 
         Cell[
          StyleData["Title"], CellFrame -> {{0, 0}, {1, 0}}, CellDingbat -> 
          None, CellMargins -> {{27, Inherited}, {8, 34}}, 
          CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> False, 
          CellFrameMargins -> 4, CellFrameColor -> 
          RGBColor[1, 0.611765, 0.317647], DefaultNewInlineCellStyle -> 
          "None", LineSpacing -> {1, 2}, FontFamily -> "Candara", FontSize -> 
          24, FontWeight -> "Plain"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{0, 0}, {0.5, 0}}, 
             ShowGroupOpener -> True, 
             CellMargins -> {{60, Inherited}, {8, 12}}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", FontFamily -> 
             "Candara", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
             "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "Masked" -> False, "Outline" -> False, "Shadow" -> False, 
               "StrikeThrough" -> False, "Underline" -> False}], 
            Cell[
             BoxData[" "], "Input", CellFrame -> {{0, 0}, {0.5, 0}}, 
             CellChangeTimes -> {3.5689766331932898`*^9}, FontFamily -> 
             "Candara"]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> None, ShowGroupOpener -> 
             True, CellMargins -> {{60, Inherited}, {2, 10}}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", FontFamily -> 
             "Candara", FontSize -> 16, FontWeight -> "Plain"], 
            Cell[
             BoxData[" "], "Input", 
             CellChangeTimes -> {3.5689772404087563`*^9}, FontFamily -> 
             "Candara"]}, Open]], 
         Cell[
          StyleData["Subsubsection"], CellDingbat -> None, ShowGroupOpener -> 
          True, FontFamily -> "Candara", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontTracking -> "Plain", 
          FontVariations -> {
           "Masked" -> False, "Outline" -> False, "Shadow" -> False, 
            "StrikeThrough" -> False, "Underline" -> False}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Text", "Subsubsection", CellChangeTimes -> {3.568980449396245*^9}], 
         Cell[
          StyleData["Text"], FontFamily -> "Candara", FontSize -> 12, 
          FontWeight -> "Plain", FontSlant -> "Plain", 
          FontVariations -> {
           "StrikeThrough" -> False, "Underline" -> False}]}, Closed]]}, 
     Open]]}, Visible -> False, FrontEndVersion -> 
  "9.0 for Microsoft Windows (32-bit) (January 25, 2013)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3602334092-6566558"->{
  Cell[10859, 307, 512, 8, 70, "Print",
   CellTags->"Info3602334092-6566558"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3602334092-6566558", 30727, 789}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 80, 2, 69, "Title"],
Cell[CellGroupData[{
Cell[685, 28, 34, 0, 46, "Section"],
Cell[CellGroupData[{
Cell[744, 32, 29, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[798, 36, 111, 3, 65, "Input"],
Cell[912, 41, 235, 6, 70, "Print"],
Cell[1150, 49, 1119, 17, 70, "Output"]
}, Open  ]],
Cell[2284, 69, 652, 18, 28, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2985, 93, 52, 0, 38, "Section"],
Cell[CellGroupData[{
Cell[3062, 97, 33, 0, 31, "Subsection"],
Cell[3098, 99, 150, 3, 28, "Text"],
Cell[3251, 104, 774, 25, 65, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4074, 135, 36, 0, 46, "Section"],
Cell[4113, 137, 49, 0, 28, "Text"],
Cell[CellGroupData[{
Cell[4187, 141, 80, 2, 44, "Input"],
Cell[4270, 145, 2476, 57, 158, "Output"]
}, Open  ]],
Cell[6761, 205, 236, 5, 28, "Text"],
Cell[7000, 212, 453, 13, 62, "Text"],
Cell[7456, 227, 603, 11, 45, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8096, 243, 33, 0, 46, "Section"],
Cell[CellGroupData[{
Cell[8154, 247, 36, 0, 29, "Subsubsection"],
Cell[8193, 249, 295, 5, 45, "Text"],
Cell[CellGroupData[{
Cell[8513, 258, 160, 4, 65, "Input"],
Cell[8676, 264, 1002, 14, 70, "Output"],
Cell[9681, 280, 1004, 14, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[10734, 300, 38, 0, 23, "Subsubsection"],
Cell[CellGroupData[{
Cell[10797, 304, 59, 1, 44, "Input"],
Cell[10859, 307, 512, 8, 70, "Print",
 CellTags->"Info3602334092-6566558"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11408, 320, 284, 8, 85, "Input"],
Cell[11695, 330, 1049, 16, 70, "Output"],
Cell[12747, 348, 1151, 19, 70, "Output"],
Cell[13901, 369, 1114, 18, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[15064, 393, 55, 0, 23, "Subsubsection"],
Cell[15122, 395, 273, 7, 28, "Text"],
Cell[15398, 404, 29, 0, 28, "Text"],
Cell[CellGroupData[{
Cell[15452, 408, 83, 2, 44, "Input"],
Cell[15538, 412, 3149, 78, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18724, 495, 105, 2, 44, "Input"],
Cell[18832, 499, 2563, 60, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[21456, 566, 106, 1, 38, "Section"],
Cell[21565, 569, 172, 5, 28, "Text"],
Cell[CellGroupData[{
Cell[21762, 578, 225, 5, 44, "Input"],
Cell[21990, 585, 2438, 56, 158, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24465, 646, 130, 2, 44, "Input"],
Cell[24598, 650, 755, 12, 31, "Output"]
}, Open  ]],
Cell[25368, 665, 179, 4, 28, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
