(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     23398,        778]
NotebookOptionsPosition[     16005,        575]
NotebookOutlinePosition[     21343,        702]
CellTagsIndexPosition[     21258,        697]
WindowFrame->Generic*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["scalar functions", "Title"],

Cell[CellGroupData[{

Cell["Package and metrics", "Section"],

Cell[CellGroupData[{

Cell["Package", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Needs", "[", "\"\<ccgrg`\>\"", "]"}], 
  ";"}], "\n", "version"}], "Input"],

Cell[BoxData[
 StyleBox["\<\"ccgrg - Copernicus Center General Relativity Package for \
Mathematica 8\"\>",
  StripOnInput->False,
  FontFamily->"Helvetica",
  FontSlant->Italic]], "Print",
 CellChangeTimes->{3.5721057020630407`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Tue 12 Mar 2013 18:13:51\"\>", ",", "50072"}], "}"}]], "Output",
 CellChangeTimes->{3.572105702156641*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Coordinates and the metric tensor", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"K", ",", "\[Sigma]"}], "]"}], ";", 
  RowBox[{"K", "==", "0"}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"x", "=", 
    RowBox[{"{", 
     RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], "}"}]}], 
   ";"}], " ", "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "=", 
    RowBox[{"Evaluate", "[", 
     RowBox[{"DiagonalMatrix", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "^", "2"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "^", "2"}], " ", 
         RowBox[{
          RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}], "^", "2"}]}]}], "}"}], 
      "]"}], "]"}]}], ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"$Assumptions", "=", 
    RowBox[{
     RowBox[{"0", "<", "\[CurlyTheta]"}], "&&", 
     RowBox[{"\[CurlyTheta]", "<", "\[Pi]"}], "&&", 
     RowBox[{"0", "<", "\[Chi]"}]}]}], ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{"open", "[", 
   RowBox[{"x", ",", "g"}], "]"}], ";"}]}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Scalar function", "Section"],

Cell[CellGroupData[{

Cell["Metrics", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Outer", "[", 
   RowBox[{"g\[DoubleDagger]", ",", "all", ",", "all"}], "]"}], "//", 
  "MF"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", 
      SuperscriptBox[
       RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "2"], "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5721057035918436`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introducing scalar function", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "=", 
  RowBox[{"\[Psi]", "@@", "x"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Psi]", "[", 
  RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], 
  "]"}]], "Output",
 CellChangeTimes->{3.5721057037010436`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derivatives", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"partialD", "[", "\[CapitalPsi]", "]"}], "[", "2", "]"}], "\n", 
 RowBox[{
  RowBox[{"partialD", "[", "\[CapitalPsi]", "]"}], "[", 
  RowBox[{"2", ",", "2"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"partialD", "[", "\[CapitalPsi]", "]"}], "[", 
  RowBox[{"2", ",", "2", ",", "2"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[Psi]", 
   TagBox[
    RowBox[{"(", 
     RowBox[{"0", ",", "1", ",", "0"}], ")"}],
    Derivative],
   MultilineFunction->None], "[", 
  RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], 
  "]"}]], "Output",
 CellChangeTimes->{3.572105703841444*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[Psi]", 
   TagBox[
    RowBox[{"(", 
     RowBox[{"0", ",", "2", ",", "0"}], ")"}],
    Derivative],
   MultilineFunction->None], "[", 
  RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], 
  "]"}]], "Output",
 CellChangeTimes->{3.572105703841444*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[Psi]", 
   TagBox[
    RowBox[{"(", 
     RowBox[{"0", ",", "3", ",", "0"}], ")"}],
    Derivative],
   MultilineFunction->None], "[", 
  RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], 
  "]"}]], "Output",
 CellChangeTimes->{3.572105703841444*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"covariantD", "[", "\[CapitalPsi]", "]"}], "[", "2", "]"}], "\n", 
 RowBox[{
  RowBox[{"covariantD", "[", "\[CapitalPsi]", "]"}], "[", 
  RowBox[{"2", ",", "2"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"covariantD", "[", "\[CapitalPsi]", "]"}], "[", 
  RowBox[{"2", ",", "2", ",", "2"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[Psi]", 
   TagBox[
    RowBox[{"(", 
     RowBox[{"0", ",", "1", ",", "0"}], ")"}],
    Derivative],
   MultilineFunction->None], "[", 
  RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], 
  "]"}]], "Output",
 CellChangeTimes->{3.572105703997444*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[Psi]", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "2", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], "]"}], "+", 
  RowBox[{
   RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Sigma]", "\[Prime]",
     MultilineFunction->None], "[", "\[Chi]", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Psi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.5721057040130444`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Sigma]", "\[Prime]",
      MultilineFunction->None], "[", "\[Chi]", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Psi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], "]"}]}], 
  "+", 
  RowBox[{
   SuperscriptBox["\[Psi]", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "3", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], "]"}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Sigma]", "\[Prime]",
     MultilineFunction->None], "[", "\[Chi]", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Psi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.5721057041066446`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laplacian", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "\[EmptyDownTriangle]"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"\[EmptyDownTriangle] is short name for covariantD\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.572105704465445*^9},
 CellTags->"Info3572109304-1605871"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   UnderoverscriptBox["\[Sum]", "m", "dim"], 
   RowBox[{
    RowBox[{"\[EmptyDownTriangle]", "[", "\[CapitalPsi]", "]"}], "[", 
    RowBox[{"m", ",", 
     RowBox[{"-", "m"}]}], "]"}]}], " ", "//", "Simplify"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "2"]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"Csc", "[", "\[CurlyTheta]", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Psi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], "]"}]}], 
    "+", 
    RowBox[{
     RowBox[{"Cot", "[", "\[CurlyTheta]", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Psi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], "]"}]}], 
    "+", 
    RowBox[{
     SuperscriptBox["\[Psi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], "]"}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Sigma]", "\[Prime]",
       MultilineFunction->None], "[", "\[Chi]", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Psi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], "]"}]}], 
    "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Psi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Chi]", ",", "\[CurlyTheta]", ",", "\[CurlyPhi]"}], "]"}]}]}],
    ")"}]}]], "Output",
 CellChangeTimes->{3.572105705510647*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ricci scalar", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sRicciR", "[", "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "-", 
   SuperscriptBox[
    RowBox[{"Cot", "[", "\[CurlyTheta]", "]"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{"Csc", "[", "\[CurlyTheta]", "]"}], "2"], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Sigma]", "\[Prime]",
       MultilineFunction->None], "[", "\[Chi]", "]"}], "2"]}], "-", 
   RowBox[{"4", " ", 
    RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Sigma]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "\[Chi]", "]"}]}]}], 
  SuperscriptBox[
   RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "2"]]], "Output",
 CellChangeTimes->{3.5721057058382473`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"covariantD", "[", "sRicciR", "]"}], "[", "1", "]"}], "//", 
  "Simplify"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"covariantD", "[", "sRicciR", "]"}], "[", 
   RowBox[{"1", ",", "1"}], "]"}], "//", "Simplify"}]}], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Sigma]", "\[Prime]",
        MultilineFunction->None], "[", "\[Chi]", "]"}], "-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Sigma]", "\[Prime]",
         MultilineFunction->None], "[", "\[Chi]", "]"}], "3"], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Sigma]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "\[Chi]", "]"}]}]}], ")"}]}], 
   SuperscriptBox[
    RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "3"]]}]], "Output",
 CellChangeTimes->{3.572105706243848*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Sigma]", "\[Prime]",
          MultilineFunction->None], "[", "\[Chi]", "]"}], "4"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Sigma]", "\[Prime]",
          MultilineFunction->None], "[", "\[Chi]", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Sigma]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "\[Chi]", "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Sigma]", "\[Prime]",
         MultilineFunction->None], "[", "\[Chi]", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Sigma]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "\[Chi]", "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Sigma]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "\[Chi]", "]"}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["\[Sigma]", 
            TagBox[
             RowBox[{"(", "4", ")"}],
             Derivative],
            MultilineFunction->None], "[", "\[Chi]", "]"}]}]}], ")"}]}]}], 
     ")"}]}], 
   SuperscriptBox[
    RowBox[{"\[Sigma]", "[", "\[Chi]", "]"}], "4"]]}]], "Output",
 CellChangeTimes->{3.572105706415448*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Carminati - McLanaghan invariants", "Subsection"],

Cell[TextData[{
 "(see >> ",
 Cell[BoxData[
  TagBox[
   TagBox[
    ButtonBox[
     PaneSelectorBox[{False->
      StyleBox["\<\"CM_invariants\"\>", "Hyperlink",
       StripOnInput->False,
       FontFamily->"Candara",
       FontSize->12], True->
      StyleBox["\<\"CM_invariants\"\>", "HyperlinkActive",
       StripOnInput->False,
       FontFamily->"Candara",
       FontSize->12]}, Dynamic[
       CurrentValue["MouseOver"]],
      FrameMargins->0,
      ImageSize->Automatic],
     Appearance->None,
     ButtonFunction:>
      Module[{$CellContext`stan$}, $CellContext`stan$ = {WindowSize -> {
            Scaled[3/4], 
            Scaled[1]}, WindowMargins -> {{Automatic, 0}, {Automatic, 0}}}; 
       NotebookOpen[
        "D:\\Nauka\\Research\\1_Nauka_L\\Problem2\\techniki\\ccgrg\\opisy\\\
opis73\\_files\\advanced\\CM_invariants.nb", 
         Apply[Sequence, $CellContext`stan$]]],
     Evaluator->Automatic,
     Method->"Preemptive"],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]]],
  CellChangeTimes->{{3.5694175666110783`*^9, 3.569417574863493*^9}}],
 ")"
}], "Text",
 CellChangeTimes->{3.5721056743573923`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{
  Scaled[
   Rational[3, 4]], 
  Scaled[1]},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
WindowFrame->"Generic",
ShowSelection->True,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (October 6, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Background colors", "Subsection", 
       CellChangeTimes -> {3.5689765261927013`*^9}], 
      Cell[
       CellGroupData[{
         Cell[
         "Background", "Subsubsection", 
          CellChangeTimes -> {3.568976573569985*^9}], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, 
          CellBracketOptions -> {"Color" -> GrayLevel[0]}, 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 9, Background -> GrayLevel[0.94902]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Background for input cell", "Subsubsection", 
          CellChangeTimes -> {3.5689765583287582`*^9}], 
         Cell[
          StyleData["Input"], CellMargins -> {{66, 10}, {5, 7}}, Evaluatable -> 
          True, CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
          True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
          DefaultFormatType -> DefaultInputFormatType, 
          "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
          FormatType -> InputForm, ShowStringCharacters -> True, NumberMarks -> 
          True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, 
          CounterIncrements -> "Input", FontFamily -> "Helvetica", FontSize -> 
          12, FontWeight -> "Bold", Background -> 
          RGBColor[
           0.8941176470588236, 0.8941176470588236, 0.8941176470588236]]}, 
        Closed]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Headings and text", "Subsection", 
       CellChangeTimes -> {3.568981227090465*^9}, FontFamily -> "Candara"], 
      Cell[
       CellGroupData[{
         Cell[
         "Headings", "Subsubsection", 
          CellChangeTimes -> {3.5689812390088863`*^9}], 
         Cell[
          StyleData["Title"], CellFrame -> {{0, 0}, {1, 0}}, CellDingbat -> 
          None, CellMargins -> {{27, Inherited}, {8, 34}}, 
          CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> False, 
          CellFrameMargins -> 4, CellFrameColor -> 
          RGBColor[1, 0.611765, 0.317647], DefaultNewInlineCellStyle -> 
          "None", LineSpacing -> {1, 2}, FontFamily -> "Candara", FontSize -> 
          24, FontWeight -> "Plain"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{0, 0}, {0.5, 0}}, 
             ShowGroupOpener -> True, 
             CellMargins -> {{60, Inherited}, {8, 12}}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", FontFamily -> 
             "Candara", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
             "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "Masked" -> False, "Outline" -> False, "Shadow" -> False, 
               "StrikeThrough" -> False, "Underline" -> False}], 
            Cell[
             BoxData[" "], "Input", CellFrame -> {{0, 0}, {0.5, 0}}, 
             CellChangeTimes -> {3.5689766331932898`*^9}, FontFamily -> 
             "Candara"]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> None, ShowGroupOpener -> 
             True, CellMargins -> {{60, Inherited}, {2, 10}}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", FontFamily -> 
             "Candara", FontSize -> 16, FontWeight -> "Plain"], 
            Cell[
             BoxData[" "], "Input", 
             CellChangeTimes -> {3.5689772404087563`*^9}, FontFamily -> 
             "Candara"]}, Open]], 
         Cell[
          StyleData["Subsubsection"], CellDingbat -> None, ShowGroupOpener -> 
          True, FontFamily -> "Candara", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontTracking -> "Plain", 
          FontVariations -> {
           "Masked" -> False, "Outline" -> False, "Shadow" -> False, 
            "StrikeThrough" -> False, "Underline" -> False}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Text", "Subsubsection", CellChangeTimes -> {3.568980449396245*^9}], 
         Cell[
          StyleData["Text"], FontFamily -> "Candara", FontSize -> 12, 
          FontWeight -> "Plain", FontSlant -> "Plain", 
          FontVariations -> {
           "StrikeThrough" -> False, "Underline" -> False}]}, Closed]]}, 
     Open]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Microsoft Windows (32-bit) (October 6, 2011)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3572109304-1605871"->{
  Cell[8303, 318, 198, 4, 40, "Print",
   CellTags->"Info3572109304-1605871"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3572109304-1605871", 21155, 691}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 33, 0, 76, "Title"],
Cell[CellGroupData[{
Cell[638, 26, 38, 0, 46, "Section"],
Cell[CellGroupData[{
Cell[701, 30, 29, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[755, 34, 111, 3, 65, "Input"],
Cell[869, 39, 233, 6, 23, "Print"],
Cell[1105, 47, 150, 3, 30, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1304, 56, 55, 0, 25, "Subsection"],
Cell[1362, 58, 141, 4, 44, "Input"],
Cell[1506, 64, 986, 31, 165, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2541, 101, 34, 0, 38, "Section"],
Cell[CellGroupData[{
Cell[2600, 105, 29, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[2654, 109, 139, 4, 44, "Input"],
Cell[2796, 115, 913, 26, 63, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3758, 147, 49, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[3832, 151, 90, 2, 44, "Input"],
Cell[3925, 155, 167, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4141, 165, 33, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[4199, 169, 329, 8, 85, "Input"],
Cell[4531, 179, 306, 10, 30, "Output"],
Cell[4840, 191, 306, 10, 30, "Output"],
Cell[5149, 203, 306, 10, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5492, 218, 335, 8, 85, "Input"],
Cell[5830, 228, 306, 10, 30, "Output"],
Cell[6139, 240, 767, 24, 30, "Output"],
Cell[6909, 266, 1223, 39, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8181, 311, 31, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[8237, 315, 63, 1, 44, "Input"],
Cell[8303, 318, 198, 4, 40, "Print",
 CellTags->"Info3572109304-1605871"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8538, 327, 257, 7, 68, "Input"],
Cell[8798, 336, 2050, 64, 73, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10897, 406, 34, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[10956, 410, 55, 1, 44, "Input"],
Cell[11014, 413, 699, 19, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11750, 437, 271, 8, 65, "Input"],
Cell[12024, 447, 799, 24, 53, "Output"],
Cell[12826, 473, 1880, 54, 53, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14755, 533, 55, 0, 31, "Subsection"],
Cell[14813, 535, 1152, 35, 31, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
